package Tree::To::Text;

our $DATE = '2021-05-06'; # DATE
our $VERSION = '0.061'; # VERSION

1;
# ABSTRACT: Show a tree object structure as text

__END__

=pod

=encoding UTF-8

=head1 NAME

Tree::To::Text - Show a tree object structure as text

=head1 VERSION

This document describes version 0.061 of Tree::To::Text (from Perl distribution Tree-To-Text), released on 2021-05-06.

=head1 DESCRIPTION

This distribution contains several modules for convenient showing of tree object
structure to text:

=over

=item * L<Tree::To::TextLines>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Tree-To-Text>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Tree-To-Text>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Tree-To-Text/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
